function RFT(smdata_mgh, contrastdir, avgdir, label, clust_th, FWE)
% RFT.m
% Syntax:
%RFT(smdata_mgh, contrastdir, avgdir, label, clust_th, FWE)
%
%Performs Random Field Theory correction for Freesurfer data. You need to
%have previously generated a Freesurfer's glmdir.
%//jbernal 2010.
%
%Arguments:
%smdata_mgh: Complete path and name of the .mgh file containing the 
%smoothed data.
%contrastdir: Directory of the freesurfer generated sig.mgh (known in 
%freesurfer as 'glmdir/contrast name').
%avgdir: Directory of the freesurfer generated average subject for the
%study.
%label: Name of the label where the analysis is to be done. It must be in
%the average subject's label directory.
%clust_th: cluster-forming threshold.
%FWE: Family wise error.
%
%Output:
%Save cluster and peak-based corrected significations as .mgh files to 
%glmdir.

%% Readings
%read smoothed data
[smdata,Mvox2ras,mr_parms] = load_mgh(smdata_mgh);
smdata = squeeze(smdata)';
%stat dir
inds = strfind(contrastdir, '/');
statdir = contrastdir(1:inds(end)-1);
%read design matrix
fs_X = load([statdir '/X.mat']);
%read contrast
fid = fopen([contrastdir '/C.dat']);
tline = fgetl(fid);
fclose(fid);
contrast = fs_X.X*(str2num(tline)');
%read label
[nv,vlabel] = ReadLabelData([avgdir '/label/' label]);
%hemisphere
if label(1) == 'l'
    hemi = 'lh';
else
    hemi = 'rh';
end;
%read average surf
avgsurf = SurfStatReadSurf([avgdir '/surf/', hemi, '.inflated'],'b');

%% Statistical analysis
if isempty(clust_th)
    clust_th = 0.005;
end;
display(['Cluster and peak-based RFT correction with cluster-forming' ...
    ' threshold: ' num2str(clust_th) ' and FWE: ' num2str(FWE), ' ...']);
   
%Cluster-based and peak-based RFT correction
ndata = size(smdata);
mask = zeros(1, ndata(2));
mask(vlabel+1) = ones(1, nv);
mask = logical(mask);
slm = SurfStatLinMod(smdata, fs_X.X, avgsurf);
slm.k = 1;
slm = SurfStatT(slm, contrast);
[pval,peak,clus] = SurfStatP(slm, mask, clust_th);
pval.thresh = FWE;
sg = sign(slm.t(vlabel+1));
corr_cw_sig = zeros(1,ndata(2));
corr_pw_sig = zeros(1,ndata(2));
if ~isempty(clus)
    corr_cw_sig(vlabel+1) = -log10(pval.C(vlabel+1)).*sg;
end;
corr_pw_sig(vlabel+1) = -log10(pval.P(vlabel+1)).*sg;
display(['Saving cluster wise corrected significations to ' contrastdir ...
  '/cw_sig.mgh and peak-based corrected significations to ' contrastdir ...
  '/pw_sig.mgh']);  
save_mgh(corr_cw_sig,[contrastdir '/cw_sig.mgh'],Mvox2ras,mr_parms);
save_mgh(corr_pw_sig,[contrastdir '/pw_sig.mgh'],Mvox2ras,mr_parms);
SurfStatView(pval,avgsurf,'Significations');


