function [RFT_FDR_det, globalm0] = RFT_FDR(smdata, lowsm_sigs, avgsurf...
                          , X, contrast, vlabel, clust_th, qval, FWE, side)
% RFT_FDR.m
% Syntax:
%      [RFT_FDR_det, globalm0] = RFT_FDR(smdata, lowsm_sigs, avgsurf...
%                               , X, contrast, vlabel, clust_th, qval, FWE)
%
%Apply the hierarchical RFT-FDR correction to the smoothed data.
%//jbernal 2010.
%
%Arguments:
%smdata: nxv Matrix of smoothed data. n is number of maps and v is the 
%number of vertices (typically 163842 for freesurfer).
%lowsm_sigs: Low smoothed freesurfer significants map.
%avgsurf: Average subject surface. In SurfStat format.
%X: Design matrix generated in freesurfer.
%contrast: Matrix of contrast.
%vlabel: Vertices on the label (0-based) where the analysis is to be done.
%clust_th: cluster-forming threshold.
%qval: FDR q-value.
%FWE: Family wise error.
%side: It is 0 for left-sided tests or 1 for right-sided tests or 2 for
%two-sided tests.
%
%Output:
%RFT_FDR_det: Detected vertices (0-based).
%globalm0: Global number of null vertices.

nlabel = length(vlabel);
ndata = size(smdata);
mask = zeros(1, ndata(2));
mask(vlabel+1) = ones(1, nlabel);
mask = logical(mask);
slm = SurfStatLinMod(smdata, X, avgsurf);
slm.k = 1;
slm = SurfStatT(slm, contrast);
[pval,peak,clus,clusid] = SurfStatP(slm, mask, clust_th);
if isempty(clus)
   RFT_cw_det = [];
else
   RFT_cw_pval = pval.C; 
   RFT_cw_det = vlabel(RFT_cw_pval(vlabel+1) <= FWE);
end;
RFT_FDR_det = [];
m1 = 0; %m1 is the global number of non-null vertices
if ~isempty(RFT_cw_det)
   vdet_ind = RFT_cw_det+1;
   b = unique(clusid(vdet_ind));
   for p=1:length(b)
       cluster = vdet_ind(clusid(vdet_ind) == b(p))-1;
       % One sided FDR thresholding inside individual clusters (0-based)
       [cluster_det,m0] = fdr_two_stage(lowsm_sigs, cluster, qval, side);
       RFT_FDR_det = [RFT_FDR_det cluster_det];
       m1 = m1+length(cluster)-m0;
   end;
end;
globalm0 = nlabel-m1;