function [vdet,m0] = fdr_two_stage(sigs, vlabel, rate, side)
% fdr_two_stage.m
% Syntax:
%      [vdet,m0] = fdr_two_stage(sigs, vlabel, rate)
%
%Benjamini's two-stage FDR method. //jbernal 2010.
%
%Arguments:
%sigs: A freesurfer significants map vector (gotten from a sig.mgh file).
%vlabel: Vertices on the label (0-based) where the analysis is to be done.
%rate: q-val for the FDR analysis.
%side: It is 0 for left-sided tests or 1 for right-sided tests or 2 for
%two-sided tests.
%
%Output:
%vdet: Detected vertices (0-based).
%m0: Estimated number of null vertices.

nv = length(vlabel);
pvals = 10.^(-abs(sigs(vlabel+1)));
%% First stage (m0 estimation)
q0 = rate/(1+rate);
pth0 = fast_fdr(pvals,q0);
% one sided-thresh
vdet0 = detection(sigs, vlabel, pth0, side);
nvdet0 = length(vdet0);
m0 = nv-nvdet0;
%% Second stage
if (nvdet0 ~= 0) && (nvdet0 ~= nv)
    % one sided-thresh
    pID = fast_fdr(pvals, q0*nv/m0);
    vdet = detection(sigs, vlabel, pID, side);
else
   vdet = vdet0; 
end;


%% Brewed function
function det = detection(sigs, vlabel, pthr, side)
thr = -log10(pthr)-log10(2);
if side == 1
    det = vlabel(sigs(vlabel+1) >= thr);
elseif side == 0
    det = vlabel(sigs(vlabel+1) <= -thr);
elseif side == 2
    thr = -log10(pthr);
    det = vlabel(abs(sigs(vlabel+1)) >= thr);
else
    error(['side must be 0 for left-sided tests or 1 for right-sided' ...
   'tests or 2 for two-sided tests']);
end;

